FB2Body class

Represents the body of an FB2 document.

Constructors

FB2Body(String body)

Properties

epigraph String?
The epigraph of the document.
latefinal
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sections List<FB2Section>?
The sections of the document.
latefinal
title String?
The title of the document.
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited